@@ -254,30 +254,30 @@ TaylorDiagram <- function(mydata, obs = "obs", mod = "mod", group = NULL, type =
     ##extra.args setup
     extra.args <- list(...)
 
-    #label controls (some local xlab, ylab management in code)
+                                        #label controls (some local xlab, ylab management in code)
     extra.args$xlab <- if("xlab" %in% names(extra.args))
-                           quickText(extra.args$xlab, auto.text) else NULL
+        quickText(extra.args$xlab, auto.text) else NULL
     extra.args$ylab <- if("ylab" %in% names(extra.args))
-                           quickText(extra.args$ylab, auto.text) else NULL
+        quickText(extra.args$ylab, auto.text) else NULL
     extra.args$main <- if("main" %in% names(extra.args))
-                           quickText(extra.args$main, auto.text) else quickText("", auto.text)
+        quickText(extra.args$main, auto.text) else quickText("", auto.text)
 
-    #layout (also code in body)
+                                        #layout (also code in body)
     if(!"layout" %in% names(extra.args))
         extra.args$layout <- NULL
 
-    #pch, cex (also code in body)
+                                        #pch, cex (also code in body)
     if(!"pch" %in% names(extra.args))
         extra.args$pch <- 20
     if(!"cex" %in% names(extra.args))
         extra.args$cex <- 2
 
-## #######################################################################################
+    ## #######################################################################################
 
     ## check to see if two data sets are present
     combine <- FALSE
 
-     if (length(mod) ==2) combine <- TRUE
+    if (length(mod) ==2) combine <- TRUE
 
     if (any(type %in%  openair:::dateTypes)) {
 
@@ -308,12 +308,12 @@ TaylorDiagram <- function(mydata, obs = "obs", mod = "mod", group = NULL, type =
 
     ## data checks, for base and new data if necessary
 
-        mydata <- openair:::checkPrep(mydata, vars, type)
+    mydata <- openair:::checkPrep(mydata, vars, type)
 
-        ## remove missing data
-        mydata <- na.omit(mydata)
+    ## remove missing data
+    mydata <- na.omit(mydata)
 
-        mydata <- cutData(mydata, type, ...)
+    mydata <- cutData(mydata, type, ...)
 
     if (missing(group)) {
 
@@ -347,7 +347,7 @@ TaylorDiagram <- function(mydata, obs = "obs", mod = "mod", group = NULL, type =
 
     results <- ddply(mydata, c(group, type), calcStats, obs = obs, mod = mod[1])
 
-
+    results.new <- NULL
     if (combine) results.new <- ddply(mydata, c(group, type), calcStats,
                                       obs = obs, mod = mod[2])
 
@@ -400,7 +400,7 @@ TaylorDiagram <- function(mydata, obs = "obs", mod = "mod", group = NULL, type =
             extra.args$skip <- skip
     }
     if(!"skip" %in% names(extra.args))
-         extra.args$skip <- FALSE
+        extra.args$skip <- FALSE
 
 
     ## proper names of labelling ##############################################################################
@@ -428,133 +428,45 @@ TaylorDiagram <- function(mydata, obs = "obs", mod = "mod", group = NULL, type =
 
     maxsd <- 1.2 * max(results$sd.obs, results$sd.mod)
 
-    #xlim, ylim handling
+                                        #xlim, ylim handling
     if(!"ylim" %in% names(extra.args))
         extra.args$ylim <- 1.12 * c(0, maxsd)
     if(!"xlim" %in% names(extra.args))
         extra.args$xlim <- 1.12 * c(0, maxsd)
 
-    #xlab, ylab local management
+    ## xlab, ylab local management
     if(is.null(extra.args$ylab))
         extra.args$ylab <- if(normalise) "standard deviation (normalised)" else "standard deviation"
     if(is.null(extra.args$xlab))
         extra.args$xlab <- extra.args$ylab
 
-    #plot
+    ## plot
     xyplot.args <- list(x = myform,  data = results, groups = results$MyGroupVar,
-                  aspect = 1,
-                  type = "n",
-                  as.table = TRUE,
-                  scales = scales,
-                  key = key,
-                  par.strip.text = list(cex = 0.8),
-                  strip = strip,
-                  strip.left = strip.left,
-                  panel =  panel.superpose,
-                  panel.groups = function(x, y, col.symbol, col, type, col.line, lty, lwd,
-                  group.number,
+                        aspect = 1,
+                        type = "n",
+                        as.table = TRUE,
+                        scales = scales,
+                        key = key,
+                        par.strip.text = list(cex = 0.8),
+                        strip = strip,
+                        strip.left = strip.left,
+                        panel =  function(x, y, ...) {
 
-                  subscripts,...)
-              {
+                            ## annotate each panel but don't need to do this for each grouping value
+                            panel.taylor.setup(x, y, results = results, maxsd = maxsd,
+                                               cor.col = cor.col, rms.col = rms.col, ...)
 
-                  ## draw the diagram
-                  if (group.number == 1) {
-                      xcurve <- cos(seq(0, pi / 2, by = 0.01)) * maxsd
-                      ycurve <- sin(seq(0, pi / 2, by = 0.01)) * maxsd
-                      llines(xcurve, ycurve, col = "black")
+                            ## plot data in each panel
+                            panel.superpose(x, y, panel.groups = panel.taylor, ...,
+                                            results = results, results.new = results.new,
+                                            combine = combine, myColors = myColors,
+                                            arrow.lwd = arrow.lwd)
+                        })
 
-                      xcurve <- cos(seq(0, pi / 2, by = 0.01)) * results$sd.obs[subscripts]
-                      ycurve <- sin(seq(0, pi / 2, by = 0.01)) * results$sd.obs[subscripts]
-                      llines(xcurve, ycurve, col = "black", lty = 5)
+    ## reset for extra.args
+    xyplot.args <- openair:::listUpdate(xyplot.args, extra.args)
 
-                      corr.lines = c(0.2, 0.4, 0.6, 0.8, 0.9)
-
-                      ## grid line with alpha transparency
-                      theCol <- t(col2rgb(cor.col)) / 255
-
-                      for (gcl in corr.lines) llines(c(0, maxsd * gcl), c(0, maxsd * sqrt(1 - gcl ^ 2)),
-                                                     col = rgb(theCol, alpha = 0.4), alpha = 0.5)
-
-                      bigtick <- acos(seq(0.1, 0.9, by = 0.1))
-                      medtick <- acos(seq(0.05, 0.95, by = 0.1))
-                      smltick <- acos(seq(0.91, 0.99, by = 0.01))
-
-                      lsegments(cos(bigtick) * maxsd, sin(bigtick) *
-                                maxsd, cos(bigtick) * 0.96 * maxsd, sin(bigtick) * 0.96 * maxsd,
-                                col = cor.col)
-
-                      lsegments(cos(medtick) * maxsd, sin(medtick) *
-                                maxsd, cos(medtick) * 0.98 * maxsd, sin(medtick) * 0.98 * maxsd,
-                                col = cor.col)
-                      lsegments(cos(smltick) * maxsd, sin(smltick) *
-                                maxsd, cos(smltick) * 0.99 * maxsd, sin(smltick) * 0.99 * maxsd,
-                                col = cor.col)
-
-                      ## arcs for standard deviations (3 by default)
-                      gamma <- pretty(c(0, maxsd), n = 5)
-                      if (gamma[length(gamma)] > maxsd)
-                          gamma <- gamma[-length(gamma)]
-                      labelpos <- seq(45, 70, length.out = length(gamma))
-
-                      ## from plotrix
-                      for (gindex in 1:length(gamma)) {
-                          xcurve <- cos(seq(0, pi, by = 0.03)) * gamma[gindex] +
-                              results$sd.obs[subscripts]
-                          endcurve <- which(xcurve < 0)
-                          endcurve <- ifelse(length(endcurve), min(endcurve) - 1, 105)
-                          ycurve <- sin(seq(0, pi, by = 0.03)) * gamma[gindex]
-                          maxcurve <- xcurve * xcurve + ycurve * ycurve
-                          startcurve <- which(maxcurve > maxsd * maxsd)
-                          startcurve <- ifelse(length(startcurve), max(startcurve) + 1, 0)
-
-                          llines(xcurve[startcurve : endcurve], ycurve[startcurve : endcurve],
-                                 col = rms.col, lty = 5)
-
-                          ltext(xcurve[labelpos[gindex]], ycurve[labelpos[gindex]],
-                                 gamma[gindex], cex = 0.7, col = rms.col, pos = 1,
-                                srt = 0, font = 2)
-
-                          ltext(1.1 * maxsd, 1.05 * maxsd, "centred\nRMS error", cex = 0.7,
-                                col = rms.col, pos = 2)
-                      }
-
-                      ## angles for R key
-                      angles <- 180 * c(bigtick, acos(c(0.95, 0.99))) / pi
-
-                      ltext(cos(c(bigtick, acos(c(0.95, 0.99)))) *
-                            1.06 * maxsd, sin(c(bigtick, acos(c(0.95, 0.99)))) *
-                            1.06 * maxsd, c(seq(0.1, 0.9, by = 0.1), 0.95, 0.99), cex = 0.7,
-                            adj = 0.5, srt = angles, col = cor.col)
-
-                      ltext(0.82 * maxsd, 0.82 * maxsd, "correlation", srt = 315, cex = 0.7,
-                            col = cor.col)
-
-
-                      ## measured point and text
-                      lpoints(results$sd.obs[subscripts], 0, pch = 20, col = "purple", cex = 1.5)
-                      ltext(results$sd.obs[subscripts], 0, "observed", col = "purple", cex = 0.7, pos = 3)
-
-                  }
-
-                  results <- transform(results, x = sd.mod * R, y = sd.mod * sin(acos(R)))
-
-                  if (combine) {
-                      results.new <- transform(results.new, x = sd.mod * R, y = sd.mod * sin(acos(R)))
-                      larrows(results$x[subscripts], results$y[subscripts],
-                              results.new$x[subscripts], results.new$y[subscripts],
-                              angle = 30, length = 0.1, col =  myColors[group.number], lwd = arrow.lwd)
-                  } else {
-
-                      lpoints(results$x[subscripts], results$y[subscripts],
-                          col.symbol = myColors[group.number], ...)
-                  }
-
-              })
-
-    #reset for extra.args
-    xyplot.args<- openair:::listUpdate(xyplot.args, extra.args)
-
-    #plot
+    ## plot
     plt <- do.call(xyplot, xyplot.args)
 
 
@@ -563,7 +475,7 @@ TaylorDiagram <- function(mydata, obs = "obs", mod = "mod", group = NULL, type =
     output <- list(plot = plt, data = newdata, call = match.call())
     class(output) <- "openair"
 
-                                        ## reset if greyscale
+    ## reset if greyscale
     if (length(cols) == 1 && cols == "greyscale")
         trellis.par.set("strip.background", current.strip)
 
@@ -572,6 +484,115 @@ TaylorDiagram <- function(mydata, obs = "obs", mod = "mod", group = NULL, type =
 }
 
 
+panel.taylor.setup <- function(x, y, subscripts, results, maxsd, cor.col, rms.col,
+                               col.symbol, group.number, type, ...) {
+    ## note, this assumes for each level of type there is a single measured value
+    ## therefore, only the first is used  i.e. results$sd.obs[subscripts[1]]
+    ## This does not matter if normalise = TRUE because all sd.obs = 1.
+
+    ## The data frame 'results' should contain a grouping variable 'MyGroupVar',
+    ## 'type' e.g. season, R (correlation coef), sd.obs and sd.mod
+    xcurve <- cos(seq(0, pi / 2, by = 0.01)) * maxsd
+    ycurve <- sin(seq(0, pi / 2, by = 0.01)) * maxsd
+    llines(xcurve, ycurve, col = "black")
+
+    xcurve <- cos(seq(0, pi / 2, by = 0.01)) * results$sd.obs[subscripts[1]]
+    ycurve <- sin(seq(0, pi / 2, by = 0.01)) * results$sd.obs[subscripts[1]]
+    llines(xcurve, ycurve, col = "black", lty = 5)
+
+    corr.lines <- c(0.2, 0.4, 0.6, 0.8, 0.9)
+
+    ## grid line with alpha transparency
+    theCol <- t(col2rgb(cor.col)) / 255
+
+    for (gcl in corr.lines) llines(c(0, maxsd * gcl), c(0, maxsd * sqrt(1 - gcl ^ 2)),
+                                   col = rgb(theCol, alpha = 0.4), alpha = 0.5)
+
+    bigtick <- acos(seq(0.1, 0.9, by = 0.1))
+    medtick <- acos(seq(0.05, 0.95, by = 0.1))
+    smltick <- acos(seq(0.91, 0.99, by = 0.01))
+
+    lsegments(cos(bigtick) * maxsd, sin(bigtick) *
+              maxsd, cos(bigtick) * 0.96 * maxsd, sin(bigtick) * 0.96 * maxsd,
+              col = cor.col)
+
+    lsegments(cos(medtick) * maxsd, sin(medtick) *
+              maxsd, cos(medtick) * 0.98 * maxsd, sin(medtick) * 0.98 * maxsd,
+              col = cor.col)
+    lsegments(cos(smltick) * maxsd, sin(smltick) *
+              maxsd, cos(smltick) * 0.99 * maxsd, sin(smltick) * 0.99 * maxsd,
+              col = cor.col)
+
+    ## arcs for standard deviations (3 by default)
+    gamma <- pretty(c(0, maxsd), n = 5)
+    if (gamma[length(gamma)] > maxsd)
+        gamma <- gamma[-length(gamma)]
+    labelpos <- seq(45, 70, length.out = length(gamma))
+
+    ## some from plotrix
+    for (gindex in 1:length(gamma)) {
+        xcurve <- cos(seq(0, pi, by = 0.03)) * gamma[gindex] +
+            results$sd.obs[subscripts[1]]
+        endcurve <- which(xcurve < 0)
+        endcurve <- ifelse(length(endcurve), min(endcurve) - 1, 105)
+        ycurve <- sin(seq(0, pi, by = 0.03)) * gamma[gindex]
+        maxcurve <- xcurve * xcurve + ycurve * ycurve
+        startcurve <- which(maxcurve > maxsd * maxsd)
+        startcurve <- ifelse(length(startcurve), max(startcurve) + 1, 0)
+
+        llines(xcurve[startcurve : endcurve], ycurve[startcurve : endcurve],
+               col = rms.col, lty = 5)
+        ltext(xcurve[labelpos[gindex]], ycurve[labelpos[gindex]],
+              gamma[gindex], cex = 0.7, col = rms.col, pos = 1,
+              srt = 0, font = 2)
+
+        ltext(1.1 * maxsd, 1.05 * maxsd, "centred\nRMS error", cex = 0.7,
+              col = rms.col, pos = 2)
+    }
+
+    ## angles for R key
+    angles <- 180 * c(bigtick, acos(c(0.95, 0.99))) / pi
+
+    ltext(cos(c(bigtick, acos(c(0.95, 0.99)))) *
+          1.06 * maxsd, sin(c(bigtick, acos(c(0.95, 0.99)))) *
+          1.06 * maxsd, c(seq(0.1, 0.9, by = 0.1), 0.95, 0.99), cex = 0.7,
+          adj = 0.5, srt = angles, col = cor.col)
+
+    ltext(0.82 * maxsd, 0.82 * maxsd, "correlation", srt = 315, cex = 0.7,
+          col = cor.col)
+
+
+    ## measured point and text
+    lpoints(results$sd.obs[subscripts[1]], 0, pch = 20, col = "purple", cex = 1.5)
+    ltext(results$sd.obs[subscripts[1]], 0, "observed", col = "purple", cex = 0.7, pos = 3)
+
+}
+
+
+panel.taylor <- function(x, y, subscripts, results, results.new, maxsd, cor.col,
+                         rms.col, combine, col.symbol, myColors, group.number,
+                         type, arrow.lwd, ...) {
+
+    R <- NULL; sd.mod <- NULL ## avoid R NOTEs
+
+    ## Plot actual results by type and group if given
+    results <- transform(results, x = sd.mod * R, y = sd.mod * sin(acos(R)))
+
+    if (combine) {
+        results.new <- transform(results.new, x = sd.mod * R, y = sd.mod * sin(acos(R)))
+        larrows(results$x[subscripts], results$y[subscripts],
+                results.new$x[subscripts], results.new$y[subscripts],
+                angle = 30, length = 0.1, col =  myColors[group.number], lwd = arrow.lwd)
+    } else {
+
+        lpoints(results$x[subscripts], results$y[subscripts],
+                col.symbol = myColors[group.number], ...)
+    }
+
+}
+
+
+
 
 
 
